/**sequencer.c is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui.
This is the sequencer.
 */
#include <tangle.h>
#include <glib-object.h>
#include "gamesmenu.h"
#include "startmenu.h"
#include "../jammo.h"

ClutterActor* gamesmenu_group=NULL;

/*  TODO: use signal in json
//return to startmenu
static gboolean goto_startmenu(ClutterActor *actor, ClutterEvent *event, gpointer data) {
	clutter_actor_hide(gamesmenu_group);
	show_startmenu();
	return TRUE;
}*/

gboolean start_gamesmenu()
{
	//	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
	printf("Starting gamesmenu\n");

	ClutterActor* mainview;

	mainview = jammo_get_actor_by_id("main-views-widget");
	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);


	gamesmenu_group = jammo_get_actor_by_id("gamesmenu-view");
	clutter_actor_show (CLUTTER_ACTOR(gamesmenu_group));

	return FALSE;
}
